==> xmonad-extras-0.17.1-11-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad-extras
version:              0.17.1
visibility:           public
id:                   xmonad-extras-0.17.1-7TyNeWOgWqaC7efr5oGW4S
key:                  xmonad-extras-0.17.1-7TyNeWOgWqaC7efr5oGW4S
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  098f7a9056aa1c8caf2ee1394feda838
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.2.8/site-local/xmonad-extras-0.17.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xmonad-extras-0.17.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.1-7TyNeWOgWqaC7efr5oGW4S
depends:
    X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu
    alsa-mixer-0.3.0.1-1KxmuurdBLpGRGNO2LOWxI base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-DHCfUfF4oE79LQSK3RXSw5
    hint-0.9.0.6-IZ8BK2Qxgqt36jSkyhX4zq
    libmpd-0.10.0.0-H0rNIiQ4RJV5czIeNyWPtf mtl-2.2.2
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
    xmonad-0.18.0-6At3bkLng0JAXdyNdys7Xb
    xmonad-contrib-0.18.0-DPPKc5wmSbQEX8VShIk3hy

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-12-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-LUM4empLuOiCVDpdiLdZPL
key:                  xmonad-extras-0.17.2-LUM4empLuOiCVDpdiLdZPL
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  028bd0db1aebc33f76c64ad90d5ec10e
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.2.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-LUM4empLuOiCVDpdiLdZPL
depends:
    X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu
    alsa-mixer-0.3.0.1-1KxmuurdBLpGRGNO2LOWxI base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-LiIJbsXaEdyKrZjHrptIur
    hint-0.9.0.6-JRt1ievlEhSB0khxGtOG7
    libmpd-0.10.0.0-ujnzYYcNvt8E4Eyqg0IPv mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
    xmonad-0.18.0-Ckn89P9uvIqDsRNnvZERoz
    xmonad-contrib-0.18.1-FQu6rofdRA37QeVbXPSWh

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
